@@ -31,12 +31,10 @@ G_BEGIN_DECLS
 #define GTH_TYPE_FILE_VIEW               (gth_file_view_get_type ())
 #define GTH_FILE_VIEW(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTH_TYPE_FILE_VIEW, GthFileView))
 #define GTH_IS_FILE_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTH_TYPE_FILE_VIEW))
-#define GTH_FILE_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GTH_TYPE_FILE_VIEW, GthFileViewIface))
+#define GTH_FILE_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GTH_TYPE_FILE_VIEW, GthFileViewInterface))
 
 typedef struct _GthFileView GthFileView;
-typedef struct _GthFileViewIface GthFileViewIface;
-
-#define THUMBNAIL_BORDER (8 * 2)
+typedef struct _GthFileViewInterface GthFileViewInterface;
 
 typedef enum  {
 	GTH_VISIBILITY_NONE,
@@ -52,22 +50,23 @@ typedef enum {
 	GTH_FILE_VIEW_RENDERER_TEXT
 } GthFileViewRendererType;
 
-struct _GthFileViewIface {
+struct _GthFileViewInterface {
 	GTypeInterface parent_iface;
 
 	/*< signals >*/
 
+	void            (*cursor_changed)                (GthFileView              *self,
+							  int                       pos);
 	void            (*file_activated)                (GthFileView              *self,
-					     	     	  GtkTreePath              *path);
+					     	     	  int                       pos);
 
 	/*< virtual functions >*/
 
-	void            (*set_model)                     (GthFileView              *self,
-							  GtkTreeModel             *model);
-	GtkTreeModel *  (*get_model)                     (GthFileView              *self);
 	void            (*scroll_to)                     (GthFileView              *self,
 							  int                       pos,
 							  double                    yalign);
+	void            (*set_vscroll)                   (GthFileView              *self,
+							  double                    vscroll);
 	GthVisibility   (*get_visibility)                (GthFileView              *self,
 							  int                       pos);
 	int             (*get_at_position)               (GthFileView              *self,
@@ -75,13 +74,7 @@ struct _GthFileViewIface {
 							  int                       y);
 	int             (*get_first_visible)             (GthFileView              *self);
 	int             (*get_last_visible)              (GthFileView              *self);
-	void            (*activated)                     (GthFileView              *self,
-							  int                       pos);
-	void            (*set_cursor)                    (GthFileView              *self,
-							  int                       pos);
 	int             (*get_cursor)                    (GthFileView              *self);
-	void            (*set_spacing)                   (GthFileView              *self,
-							  int                       spacing);
 	void            (*enable_drag_source)            (GthFileView              *self,
 							  GdkModifierType           start_button_mask,
 							  const GtkTargetEntry     *targets,
@@ -99,24 +92,26 @@ struct _GthFileViewIface {
 							  int                       y,
 							  guint                     time,
 			                      	          int                      *pos);
-	GtkCellLayout * (*add_renderer)                  (GthFileView              *self,
-							  GthFileViewRendererType   renderer_type,
-							  GtkCellRenderer          *renderer);
-	void            (*update_attributes)             (GthFileView              *self,
-							  GtkCellRenderer          *checkbox_renderer,
-							  GtkCellRenderer          *thumbnail_renderer,
-							  GtkCellRenderer          *text_renderer,
-							  int                       thumb_size);
-	gboolean        (*truncate_metadata)             (GthFileView              *self);
+	void            (*get_drag_dest_pos)             (GthFileView             *self,
+							  int                     *pos);
+
 };
 
 GType           gth_file_view_get_type           (void);
 void            gth_file_view_set_model          (GthFileView             *self,
 					 	  GtkTreeModel            *model);
 GtkTreeModel *  gth_file_view_get_model          (GthFileView             *self);
+void            gth_file_view_set_caption        (GthFileView             *self,
+						  const char              *attributes);
+char *          gth_file_view_get_caption        (GthFileView             *self);
+void            gth_file_view_set_thumbnail_size (GthFileView             *self,
+						  int                      value);
+gboolean        gth_file_view_get_thumbnail_size (GthFileView             *self);
 void            gth_file_view_scroll_to          (GthFileView             *self,
 						  int                      pos,
 						  double                   yalign);
+void            gth_file_view_set_vscroll        (GthFileView             *self,
+						  double                   vscroll);
 GthVisibility   gth_file_view_get_visibility     (GthFileView             *self,
 						  int                      pos);
 int             gth_file_view_get_at_position    (GthFileView             *self,
@@ -129,8 +124,6 @@ void            gth_file_view_activated          (GthFileView             *self,
 void            gth_file_view_set_cursor         (GthFileView             *self,
 						  int                      pos);
 int             gth_file_view_get_cursor         (GthFileView             *self);
-void            gth_file_view_set_spacing        (GthFileView             *self,
-						  int                      spacing);
 void            gth_file_view_enable_drag_source (GthFileView             *self,
 				      		  GdkModifierType          start_button_mask,
 				      		  const GtkTargetEntry    *targets,
@@ -148,17 +141,8 @@ void            gth_file_view_set_drag_dest_pos  (GthFileView             *self,
 			                          int                      y,
 			                          guint                    time,
 				                  int                     *pos);
-GtkCellLayout * gth_file_view_add_renderer       (GthFileView             *self,
-						  GthFileViewRendererType  renderer_type,
-						  GtkCellRenderer         *renderer);
-void            gth_file_view_update_attributes  (GthFileView              *self,
-						  GtkCellRenderer          *checkbox_renderer,
-						  GtkCellRenderer          *thumbnail_renderer,
-						  GtkCellRenderer          *text_renderer,
-						  int                       thumb_size);
-gboolean        gth_file_view_truncate_metadata  (GthFileView              *self);
-void            gth_file_view_activate_file      (GthFileView              *self,
-						  GtkTreePath              *path);
+void            gth_file_view_get_drag_dest_pos  (GthFileView             *self,
+						  int                     *pos);
 
 G_END_DECLS
 
